@@ -1,7 +1,9 @@
 from typing import List
 
+from curlylint.issue import Issue
 
-def format_compact(issues: List["Issue"]):
+
+def format_compact(issues: List[Issue]):
     sorted_issues = sorted(
         issues,
         key=lambda i: (
